==> qtjambi-xml-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiXml/QXmlDefaultHandler_shell.h <==
#ifndef QXMLDEFAULTHANDLER_SHELL_H
#define QXMLDEFAULTHANDLER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtXml/qxml.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QXmlDefaultHandler_shell : public QXmlDefaultHandler, public QtJambiShellInterface
{
public:
    QXmlDefaultHandler_shell();
    ~QXmlDefaultHandler_shell() override;

    bool attributeDecl(const QString& eName0, const QString& aName1, const QString& type2, const QString& valueDefault3, const QString& value4) override;
    bool characters(const QString& ch0) override;
    bool comment(const QString& ch0) override;
    bool endCDATA() override;
    bool endDTD() override;
    bool endDocument() override;
    bool endElement(const QString& namespaceURI0, const QString& localName1, const QString& qName2) override;
    bool endEntity(const QString& name0) override;
    bool endPrefixMapping(const QString& prefix0) override;
    bool error(const QXmlParseException& exception0) override;
    QString errorString() const override;
    bool externalEntityDecl(const QString& name0, const QString& publicId1, const QString& systemId2) override;
    bool fatalError(const QXmlParseException& exception0) override;
    bool ignorableWhitespace(const QString& ch0) override;
    bool internalEntityDecl(const QString& name0, const QString& value1) override;
    bool notationDecl(const QString& name0, const QString& publicId1, const QString& systemId2) override;
    bool processingInstruction(const QString& target0, const QString& data1) override;
    bool resolveEntity(const QString& publicId0, const QString& systemId1, QXmlInputSource*& ret2) override;
    void setDocumentLocator(QXmlLocator* locator0) override;
    bool skippedEntity(const QString& name0) override;
    bool startCDATA() override;
    bool startDTD(const QString& name0, const QString& publicId1, const QString& systemId2) override;
    bool startDocument() override;
    bool startElement(const QString& namespaceURI0, const QString& localName1, const QString& qName2, const QXmlAttributes& atts3) override;
    bool startEntity(const QString& name0) override;
    bool startPrefixMapping(const QString& prefix0, const QString& uri1) override;
    bool unparsedEntityDecl(const QString& name0, const QString& publicId1, const QString& systemId2, const QString& notationName3) override;
    bool warning(const QXmlParseException& exception0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QXmlDefaultHandler_access : public QXmlDefaultHandler
{
    jboolean __qt_attributeDecl_cref_QString_cref_QString_cref_QString_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring eName0, jstring aName1, jstring type2, jstring valueDefault3, jstring value4);
    jboolean __qt_characters_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring ch0);
    jboolean __qt_comment_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring ch0);
    jboolean __qt_endCDATA(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_endDTD(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_endDocument(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_endElement_cref_QString_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring namespaceURI0, jstring localName1, jstring qName2);
    jboolean __qt_endEntity_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    jboolean __qt_endPrefixMapping_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring prefix0);
    jboolean __qt_error_cref_QXmlParseException(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID exception0);
    jstring __qt_errorString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_externalEntityDecl_cref_QString_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jstring publicId1, jstring systemId2);
    jboolean __qt_fatalError_cref_QXmlParseException(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID exception0);
    jboolean __qt_ignorableWhitespace_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring ch0);
    jboolean __qt_internalEntityDecl_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jstring value1);
    jboolean __qt_notationDecl_cref_QString_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jstring publicId1, jstring systemId2);
    jboolean __qt_processingInstruction_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring target0, jstring data1);
    jobject __qt_resolveEntity_cref_QString_cref_QString_ref_QXmlInputSource_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring publicId0, jstring systemId1);
    void __qt_setDocumentLocator_QXmlLocator_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID locator0);
    jboolean __qt_skippedEntity_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    jboolean __qt_startCDATA(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_startDTD_cref_QString_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jstring publicId1, jstring systemId2);
    jboolean __qt_startDocument(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_startElement_cref_QString_cref_QString_cref_QString_cref_QXmlAttributes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring namespaceURI0, jstring localName1, jstring qName2, QtJambiNativeID atts3);
    jboolean __qt_startEntity_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    jboolean __qt_startPrefixMapping_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring prefix0, jstring uri1);
    jboolean __qt_unparsedEntityDecl_cref_QString_cref_QString_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jstring publicId1, jstring systemId2, jstring notationName3);
    jboolean __qt_warning_cref_QXmlParseException(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID exception0);
};

#endif // QXMLDEFAULTHANDLER_SHELL_H

==> qtjambi-xml-debuginfo-windows-x64-5.15.20.jar: sources/QtJambiXml/QXmlDefaultHandler_shell.h <==
#ifndef QXMLDEFAULTHANDLER_SHELL_H
#define QXMLDEFAULTHANDLER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtXml/qxml.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QXmlDefaultHandler_shell : public QXmlDefaultHandler, public QtJambiShellInterface
{
public:
    QXmlDefaultHandler_shell();
    ~QXmlDefaultHandler_shell() override;

    bool attributeDecl(const QString& eName0, const QString& aName1, const QString& type2, const QString& valueDefault3, const QString& value4) override;
    bool characters(const QString& ch0) override;
    bool comment(const QString& ch0) override;
    bool endCDATA() override;
    bool endDTD() override;
    bool endDocument() override;
    bool endElement(const QString& namespaceURI0, const QString& localName1, const QString& qName2) override;
    bool endEntity(const QString& name0) override;
    bool endPrefixMapping(const QString& prefix0) override;
    bool error(const QXmlParseException& exception0) override;
    QString errorString() const override;
    bool externalEntityDecl(const QString& name0, const QString& publicId1, const QString& systemId2) override;
    bool fatalError(const QXmlParseException& exception0) override;
    bool ignorableWhitespace(const QString& ch0) override;
    bool internalEntityDecl(const QString& name0, const QString& value1) override;
    bool notationDecl(const QString& name0, const QString& publicId1, const QString& systemId2) override;
    bool processingInstruction(const QString& target0, const QString& data1) override;
    bool resolveEntity(const QString& publicId0, const QString& systemId1, QXmlInputSource*& ret2) override;
    void setDocumentLocator(QXmlLocator* locator0) override;
    bool skippedEntity(const QString& name0) override;
    bool startCDATA() override;
    bool startDTD(const QString& name0, const QString& publicId1, const QString& systemId2) override;
    bool startDocument() override;
    bool startElement(const QString& namespaceURI0, const QString& localName1, const QString& qName2, const QXmlAttributes& atts3) override;
    bool startEntity(const QString& name0) override;
    bool startPrefixMapping(const QString& prefix0, const QString& uri1) override;
    bool unparsedEntityDecl(const QString& name0, const QString& publicId1, const QString& systemId2, const QString& notationName3) override;
    bool warning(const QXmlParseException& exception0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QXmlDefaultHandler_access : public QXmlDefaultHandler
{
    jboolean __qt_attributeDecl_cref_QString_cref_QString_cref_QString_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring eName0, jstring aName1, jstring type2, jstring valueDefault3, jstring value4);
    jboolean __qt_characters_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring ch0);
    jboolean __qt_comment_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring ch0);
    jboolean __qt_endCDATA(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_endDTD(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_endDocument(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_endElement_cref_QString_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring namespaceURI0, jstring localName1, jstring qName2);
    jboolean __qt_endEntity_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    jboolean __qt_endPrefixMapping_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring prefix0);
    jboolean __qt_error_cref_QXmlParseException(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID exception0);
    jstring __qt_errorString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_externalEntityDecl_cref_QString_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jstring publicId1, jstring systemId2);
    jboolean __qt_fatalError_cref_QXmlParseException(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID exception0);
    jboolean __qt_ignorableWhitespace_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring ch0);
    jboolean __qt_internalEntityDecl_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jstring value1);
    jboolean __qt_notationDecl_cref_QString_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jstring publicId1, jstring systemId2);
    jboolean __qt_processingInstruction_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring target0, jstring data1);
    jobject __qt_resolveEntity_cref_QString_cref_QString_ref_QXmlInputSource_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring publicId0, jstring systemId1);
    void __qt_setDocumentLocator_QXmlLocator_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID locator0);
    jboolean __qt_skippedEntity_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    jboolean __qt_startCDATA(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_startDTD_cref_QString_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jstring publicId1, jstring systemId2);
    jboolean __qt_startDocument(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_startElement_cref_QString_cref_QString_cref_QString_cref_QXmlAttributes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring namespaceURI0, jstring localName1, jstring qName2, QtJambiNativeID atts3);
    jboolean __qt_startEntity_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    jboolean __qt_startPrefixMapping_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring prefix0, jstring uri1);
    jboolean __qt_unparsedEntityDecl_cref_QString_cref_QString_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jstring publicId1, jstring systemId2, jstring notationName3);
    jboolean __qt_warning_cref_QXmlParseException(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID exception0);
};

#endif // QXMLDEFAULTHANDLER_SHELL_H
